==> twscrape-0.6.0.tar.gz: twscrape-0.6.0/twscrape/constants.py <==
TOKEN = "Bearer AAAAAAAAAAAAAAAAAAAAANRILgAAAAAAnNwIzUejRCOuH5E6I8xnZz4puTs%3D1Zv7ttfk8LF81IUq16cHjhLTvJu4FA33AGWWjCpTnA"  # noqa: E501

GQL_URL = "https://twitter.com/i/api/graphql"
LOGIN_URL = "https://api.twitter.com/1.1/onboarding/task.json"

OP_SearchTimeline = "L1VfBERtzc3VkBBT0YAYHA/SearchTimeline"
OP_UserByRestId = "Lxg1V9AiIzzXEiP2c8dRnw/UserByRestId"
OP_UserByScreenName = "oUZZZ8Oddwxs8Cd3iW3UEA/UserByScreenName"
OP_TweetDetail = "NmCeCgkVlsRGS1cAwqtgmw/TweetDetail"
OP_Followers = "FKV1jfu4AawGapl2KCZbQw/Followers"
OP_Following = "sKlU5dd_nanz9P2CxBt2sg/Following"
OP_Retweeters = "Gnw_Swm60cS-biSLn2OWNw/Retweeters"
OP_Favoriters = "rUyh8HWk8IXv_fvVKj3QjA/Favoriters"
OP_UserTweets = "x8SpjuBpqoww-edf0aUUKA/UserTweets"
OP_UserTweetsAndReplies = "RB2KVuVBRZe4GW8KkoVF2A/UserTweetsAndReplies"
OP_ListLatestTweetsTimeline = "2Vjeyo_L0nizAUhHe3fKyA/ListLatestTweetsTimeline"

GQL_FEATURES = {
    "blue_business_profile_image_shape_enabled": True,
    "responsive_web_graphql_exclude_directive_enabled": True,
    "verified_phone_label_enabled": False,
    "responsive_web_graphql_skip_user_profile_image_extensions_enabled": False,
    "responsive_web_graphql_timeline_navigation_enabled": True,
    "tweetypie_unmention_optimization_enabled": True,
    "vibe_api_enabled": True,
    "responsive_web_edit_tweet_api_enabled": True,
    "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
    "view_counts_everywhere_api_enabled": True,
    "longform_notetweets_consumption_enabled": True,
    "tweet_awards_web_tipping_enabled": False,
    "freedom_of_speech_not_reach_fetch_enabled": True,
    "standardized_nudges_misinfo": True,
    "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": False,
    "interactive_text_enabled": True,
    "responsive_web_text_conversations_enabled": False,
    "longform_notetweets_rich_text_read_enabled": True,
    "responsive_web_enhance_cards_enabled": False,
    "creator_subscriptions_tweet_preview_api_enabled": True,
    "longform_notetweets_inline_media_enabled": True,
    "responsive_web_media_download_video_enabled": False,
    "rweb_lists_timeline_redesign_enabled": True,
    "responsive_web_twitter_article_tweet_consumption_enabled": False,
}

==> twscrape-0.9.0.tar.gz: twscrape-0.9.0/twscrape/constants.py <==
TOKEN = "Bearer AAAAAAAAAAAAAAAAAAAAANRILgAAAAAAnNwIzUejRCOuH5E6I8xnZz4puTs%3D1Zv7ttfk8LF81IUq16cHjhLTvJu4FA33AGWWjCpTnA"  # noqa: E501

GQL_URL = "https://twitter.com/i/api/graphql"
LOGIN_URL = "https://api.twitter.com/1.1/onboarding/task.json"


OP_SearchTimeline = "lZ0GCEojmtQfiUQa5oJSEw/SearchTimeline"
OP_UserByRestId = "QdS5LJDl99iL_KUzckdfNQ/UserByRestId"
OP_UserByScreenName = "G3KGOASz96M-Qu0nwmGXNg/UserByScreenName"
OP_TweetDetail = "BbmLpxKh8rX8LNe2LhVujA/TweetDetail"
OP_Followers = "9LlZicVr2IBf4u2qW5n4-A/Followers"
OP_Following = "8cyc0OKedV_XD62fBjzxUw/Following"
OP_Retweeters = "Y2XHDEKtlJDA_ql2G3OZZQ/Retweeters"
OP_Favoriters = "zXD9lMy1-V_N1OcON9JtEQ/Favoriters"
OP_UserTweets = "VgitpdpNZ-RUIp5D1Z_D-A/UserTweets"
OP_UserTweetsAndReplies = "YlkSUg0mRBx7-EkxCvc-bw/UserTweetsAndReplies"
OP_ListLatestTweetsTimeline = "d1mUZHaqFMxe0xHI3rVc-w/ListLatestTweetsTimeline"

GQL_FEATURES = {
    "blue_business_profile_image_shape_enabled": True,
    "responsive_web_graphql_exclude_directive_enabled": True,
    "verified_phone_label_enabled": False,
    "responsive_web_graphql_skip_user_profile_image_extensions_enabled": False,
    "responsive_web_graphql_timeline_navigation_enabled": True,
    "tweetypie_unmention_optimization_enabled": True,
    "vibe_api_enabled": True,
    "responsive_web_edit_tweet_api_enabled": True,
    "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
    "view_counts_everywhere_api_enabled": True,
    "longform_notetweets_consumption_enabled": True,
    "tweet_awards_web_tipping_enabled": False,
    "freedom_of_speech_not_reach_fetch_enabled": True,
    "standardized_nudges_misinfo": True,
    "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": False,
    "interactive_text_enabled": True,
    "responsive_web_text_conversations_enabled": False,
    "longform_notetweets_rich_text_read_enabled": True,
    "responsive_web_enhance_cards_enabled": False,
    "creator_subscriptions_tweet_preview_api_enabled": True,
    "longform_notetweets_inline_media_enabled": True,
    "responsive_web_media_download_video_enabled": False,
    "rweb_lists_timeline_redesign_enabled": True,
    "responsive_web_twitter_article_tweet_consumption_enabled": False,
    "responsive_web_home_pinned_timelines_enabled": True,
    "c9s_tweet_anatomy_moderator_badge_enabled": True,
}
